

CREATE OR REPLACE FUNCTION spCreateAdjVoid(
    _StockADate DATE,
    _VendorId   bp.bpid%TYPE,
    _RefType    reftype.reftype%TYPE,
    _RefNo      stocka.refno%TYPE,
    _WhId       wh.whid%TYPE,
    _ItemId     item.itemid%TYPE,
    _PID        stock.pid%TYPE,
    _Unit       stockad.unit%TYPE,
    _Selisih    NUMERIC(19,4),
    _DeptId     dept.deptid%TYPE,
    _PrjId      prj.prjid%TYPE
) RETURNS SETOF SPStatus AS 
$BODY$
DECLARE
    _retval     SPStatus%ROWTYPE;
    _spret      SPStatus%ROWTYPE;

    _StockANo   stocka.stockano%TYPE;
    _StockANote VARCHAR;
    _StockAType stocka.stockatype%TYPE;
    _InOut      stocka.inout%TYPE;
    _NullVal    VARCHAR;
BEGIN
    _retval:=(0, 'OK');
    IF (_Selisih<0) THEN
        _InOut:='I';
        _Selisih:=ABS(_Selisih);
    ELSE 
        _InOut:='O';
        _Selisih:=_Selisih*-1;
    END IF;
    _NullVal:=NULL;
    _StockAType:=_RefType;
    _StockANote:='Penyesuaian Void Transaksi Inventory:'||COALESCE(_RefType, '')||' '||COALESCE(_RefNo, '');
    _StockANo:=fTransNoGet('STOCKA');

    SELECT INTO _spret * FROM spStockA_New(
        _StockANo, _VendorId, _StockAType, _StockADate, _InOut, _RefType, _RefNo, 
        _StockANote, TRUE, _NullVal, CAST(CURRENT_TIMESTAMP AS TIMESTAMP), _NullVal, CAST(CURRENT_TIMESTAMP AS TIMESTAMP),
        _NullVal, _NullVal, _DeptId, _PrjId
    );
    IF (_spret.ErrNo<>0) THEN
        _retval.ErrNo:=_spret.ErrNo;
        _retval.ErrMsg:=_spret.ErrMsg;
        RAISE EXCEPTION '%', _retval.ErrMsg;
    END IF;

    SELECT INTO _spret * FROM spStockAD_New(
        _StockADate, _RefType, _StockANo, CAST(1 AS INT2), _WhId, 
        _ItemId, _PId, 0, _Unit, 0, _Selisih, 
        _DeptId, _PrjId, true, _RefNo, _Selisih
    );
    IF _spret.ErrNo<>0 THEN
        _retval.ErrNo:=_spret.ErrNo;
        _retval.ErrMsg:=_spret.ErrMsg;
        RAISE EXCEPTION '%', _retval.ErrMsg;
    END IF;

    RETURN NEXT _retval;
END;
$BODY$
LANGUAGE 'plpgsql' VOLATILE;


